=====================================================================
Bioindustrial-Park: BioSTEAM's Premier Biorefinery Models and Results
=====================================================================

.. image:: http://img.shields.io/pypi/v/biorefineries.svg?style=flat
   :target: https://pypi.python.org/pypi/biorefineries
   :alt: Version_status
.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
   :target: https://github.com/yoelcortes/Bioindustrial-Park/blob/master/LICENSE.txt
   :alt: license

.. contents::

Workshops
---------
Join us on Friday, Jan 20, 9:15-10:15am CST, for a BioSTEAM workshop! 
Email biosteamdevelopmentgroup@gmail.com for details.

What is the Bioindustrial-Park?
-------------------------------

The Bioindustrial-Park is the premier repository for complete biorefinery
models and results generated with BioSTEAM. The repository is meant to 
foster accessibility and deeper communication within the BioSTEAM biorefinery 
simulation community. All biorefinery models are in the "biorefineries" 
package, as an installable package for complete biorefinery models in BioSTEAM.

Installation
------------

Get the latest version of biorefineries from
https://pypi.python.org/pypi/biorefineries/

If you have an installation of Python with pip, simple install it with:

    $ pip install biorefineries

To get the git version, run:

    $ git clone https://github.com/BioSTEAMDevelopmentGroup/Bioindustrial-Park.git

Documentation
-------------

Documentation for BioSTEAM's premier biorefinery models are available on the web:

    http://biosteam.readthedocs.io/

Bug reports
-----------

To report bugs, please use the biorefineries's Bug Tracker at:

    git://github.com/yoelcortes/Bioindustrial-Park

License information
-------------------

See ``LICENSE.txt`` for information on the terms & conditions for usage
of this software, and a DISCLAIMER OF ALL WARRANTIES.


